function hndl = tsplot(varargin)

% TSPLOT(X1,Y1,X2,Y2,...)       
%
% Plots timescale objects against each other, Y1 vs X1, Y2 vs X2 etc. Each Xn and Yn
% must be compatible (same interval sizes and types).
% 
% SPECIAL SYNTAX OPTIONS:
% - TSPLOT(X1) is the same as TSPLOT(X1,tszeros(size(X1))).
%
% - TSPLOT(X1,Y1,S1,X2,Y2,S2...) will use cell array S to determine the line-type for the 
%   plot. For example, TSPLOT(X,Y,{'r*','y-'}) will plot Y vs X with discrete intervals 
%   showing as red stars and continuous intervals showing as a yellow line. See HELP PLOT 
%   for a comprehensive list of plot options. The default behavior (no S input) is 
%   S = {'.','-'}, i.e. dots for discrete intervals and connecting lines for continuous 
%   intervals, both of the same color. If no line/color styles are specified, TSPLOT will
%   cycle through the current axis color order for each plot.
%
% - HNDL = TSPLOT(X1,Y1,...) will return a cell array HNDL containing handles to all 
%   individual interval plots. For example, if X1 and Y1 contain a discrete interval, then
%   a continuous interval, then another discrete interval, then HNDL will have one 
%   element, a vector with three handles in it
%       HNDL{1} = [h1,h2,h3]
%   where h1 is the handle to the 1st (discrete) interval, h2 the handle to the second, etc.
%   The handles for X2 and Y2 are in cell HNDL{2} and so forth.

% Ian Gravagne, 12/31/03 Baylor University

prev_hold = ishold;
if(~prev_hold)
    clf
end
hold on

if(nargin == 0)
    error('Requires at least 1 argument.')
    
elseif(nargin == 1)
    
    X = varargin{1};
    if(~isa(X,'timescale'))
        error('First argument must be a timescale object');
    end
    
    x = X(:);
    y = zeros(1,length(x));
    type = size(X);
    p = 1;
    for(i = 1:size(type,2))
        q = type(1,i);
        if(type(2,i))
            hndl{1}(i) = plot(x(p:q),y(p:q),'.');
        else
            hndl{1}(i) = plot(x(p:q),y(p:q),'-');
        end
        
        p = q+1;
    end
    
    color = get(gca,'ColorOrder');
    set(hndl{1},'Color',color(1,:)); 
    
elseif(nargin == 2)
    
    X = varargin{1};
    Y = varargin{2};
    if(~isa(X,'timescale') | ~isa(Y,'timescale'))
        error('First two arguments must be timescale objects.');
    end
    
    if(incompatible(X,Y))
        error('X,Y timescale objects are incompatible.');
    end
    
    x = X(:);
    y = Y(:);
    type = size(X);
    p = 1;
    for(i = [1:size(type,2)])
        q = type(1,i);
        if(type(2,i))
            hndl{1}(1) = plot(x(p:q),y(p:q),'.');
        else
            hndl{1}(1) = plot(x(p:q),y(p:q),'-');
        end
        p = q+1;
    end
    
    color = get(gca,'ColorOrder');
    set(hndl{1},'Color',color(1,:));
        
else
    if(iscell(varargin{3}))
        if(mod(nargin,3))
            error('Wrong number of inputs.');
        end
        
        for i = 1:nargin/3
            
            X = varargin{3*(i-1) + 1};
            Y = varargin{3*(i-1) + 2};
            S = varargin{3*(i-1) + 3};
            
            if(length(S) ~= 2)
                message = ['Argument ',num2str(3*(i-1)+3),' must be a length-2 cell array of characters.'];
                error(message);
            end
            if(~isa(X,'timescale') | ~isa(Y,'timescale'))
                message = ['Arguments ',num2str(3*(i-1) + 1),' and ',num2str(3*(i-1) + 2),' must be timescale objects.'];
                error(message);
            end
            if(incompatible(X,Y))
                message = ['Arguments ',num2str(3*(i-1) + 1),' and ',num2str(3*(i-1) + 2),' are incompatible.'];
                error(message);
            end
            
            x = X(:);
            y = Y(:);
            type = size(X);
            p = 1;
            for(j = [1:size(type,2)])
                q = type(1,j);
                if(type(2,j))
                    hndl{i}(j) = plot(x(p:q),y(p:q),S{1});
                else
                    hndl{i}(j) = plot(x(p:q),y(p:q),S{2});
                end
                p = q+1;
                
            end
        
        end
        
        
    else
        if(mod(nargin,2))
            error('Wrong number of inputs.');
        end
        
        for i = 1:nargin/2
            
            X = varargin{2*(i-1) + 1};
            Y = varargin{2*(i-1) + 2};
            
            if(~isa(X,'timescale') | ~isa(Y,'timescale'))
                message = ['Arguments ',num2str(2*(i-1) + 1),' and ',num2str(2*(i-1) + 2),' must be timescale objects.'];
                error(message);
            end
            if(incompatible(X,Y))
                message = ['Arguments ',num2str(2*(i-1) + 1),' and ',num2str(2*(i-1) + 2),' are incompatible.'];
                error(message);
            end
            
            x = X(:);
            y = Y(:);
            type = size(X);
            p = 1;
            for(j = [1:size(type,2)])
                q = type(1,j);
                if(type(2,j))
                    hndl{i}(j) = plot(x(p:q),y(p:q),'.');
                else
                    hndl{i}(j) = plot(x(p:q),y(p:q),'-');
                end
                p = q+1;
                
            end
            
            color = get(gca,'ColorOrder');
            numcolors = size(color,1);
            set(hndl{i}, 'Color', color(mod(i,numcolors),:))
        
        end
        
    end
    
end

if(nargout == 0)
    clear hndl;
end
    
if(prev_hold)
    hold on
else
    hold off
end
